# TTNOpt: Tree Tensor Netwokr Package for high-rank tensor compression
[![Documentation Status](https://readthedocs.org/projects/ttnopt/badge/?version=latest)](https://ttnopt.readthedocs.io/en/latest/)

We have developed TTNOpt, a software package that utilizes tree tensor networks (TTNs) for quantum spin systems and highdimensional data analysis.
TTNOpt provides efficient and powerful TTN computations by **locally optimizing the network structure**, guided by the entanglement pattern of the target tensors.

## Documentation
The documentation is avaibale [here](https://ttnopt.readthedocs.io/)

## Installation
One can install TTNOpt from GitHub
```
pip install git+https://github.com/Ryo-wtnb11/TTNOpt
```
or from PyPI
```
pip install ttnopt
```

## Papers
When using TTNOpt for research, please cite:
